pub fn bit_length<T>(
arg: impl IntoExpr<T>,
) -> Expr<<T as StringLengthExpr>::Output>where
T: StringLengthExpr,Expand description
Returns eight times the encoded byte length, preserving input nullability.
Maps to PostgreSQL BIT_LENGTH.
pub fn bit_length<T>(
arg: impl IntoExpr<T>,
) -> Expr<<T as StringLengthExpr>::Output>where
T: StringLengthExpr,Returns eight times the encoded byte length, preserving input nullability.
Maps to PostgreSQL BIT_LENGTH.