pub fn lower<T>(arg: impl IntoExpr<T>) -> Expr<<T as StringUnaryExpr>::Output>where
T: StringUnaryExpr,Expand description
Converts text to lowercase according to the database locale, preserving input nullability.
Maps to PostgreSQL LOWER.
pub fn lower<T>(arg: impl IntoExpr<T>) -> Expr<<T as StringUnaryExpr>::Output>where
T: StringUnaryExpr,Converts text to lowercase according to the database locale, preserving input nullability.
Maps to PostgreSQL LOWER.