pub fn trim<T>(arg: impl IntoExpr<T>) -> Expr<<T as StringUnaryExpr>::Output>where
T: StringUnaryExpr,Expand description
Removes spaces from both ends of a text expression, preserving input nullability.
Maps to PostgreSQL TRIM(expression).
pub fn trim<T>(arg: impl IntoExpr<T>) -> Expr<<T as StringUnaryExpr>::Output>where
T: StringUnaryExpr,Removes spaces from both ends of a text expression, preserving input nullability.
Maps to PostgreSQL TRIM(expression).