pub fn upper<T>(arg: impl IntoExpr<T>) -> Expr<<T as StringUnaryExpr>::Output>where
T: StringUnaryExpr,Expand description
Converts text to uppercase according to the database locale, preserving input nullability.
Maps to PostgreSQL UPPER.
pub fn upper<T>(arg: impl IntoExpr<T>) -> Expr<<T as StringUnaryExpr>::Output>where
T: StringUnaryExpr,Converts text to uppercase according to the database locale, preserving input nullability.
Maps to PostgreSQL UPPER.