title_case

Function title_case 

pub fn title_case<T>(
    expression: impl IntoExpr<T>,
) -> Expr<<T as StringUnaryExpr>::Output>
where T: StringUnaryExpr,
Converts the first letter of each alphanumeric word to upper case and the rest to lower case. Maps to PostgreSQL INITCAP.